@@ -12,6 +12,7 @@ use bls::PublicKeySet;
 use dashmap::DashMap;
 use futures::lock::Mutex;
 use log::info;
+use secured_linked_list::SecuredLinkedList;
 use sn_data_types::{
     ActorHistory, CreditAgreementProof, OwnerType, PublicKey, ReplicaEvent, SignedTransfer, Token,
     TransferAgreementProof, TransferPropagated, TransferRegistered, TransferValidated,
@@ -39,7 +40,7 @@ where
     pub id: bls::PublicKeyShare,
     pub key_index: usize,
     pub peer_replicas: PublicKeySet,
-    pub section_chain: sn_routing::SectionChain,
+    pub section_chain: SecuredLinkedList,
     pub signing: T,
 }
 
